@@ -2,15 +2,14 @@
 
 extern crate rand;
 extern crate serde;
+extern crate rayon;
 
 #[macro_use]
 extern crate ndarray;
+extern crate ndarray_parallel;
 
-#[macro_use]
-extern crate serde_derive;
 extern crate serde_json;
 
-pub mod event;
 pub mod generalized;
 pub mod timedependent;
 
